@@ -5,8 +5,7 @@
  *                     | |___ / ___ \|  _|      Framework                     *
  *                      \____/_/   \_|_|                                      *
  *                                                                            *
- * Copyright (C) 2011 - 2015                                                  *
- * Dominik Charousset <dominik.charousset (at) haw-hamburg.de>                *
+ * Copyright 2011-2018 Dominik Charousset                                     *
  *                                                                            *
  * Distributed under the terms and conditions of the BSD 3-Clause License or  *
  * (at your option) under the terms and conditions of the Boost Software      *
@@ -366,7 +365,7 @@ void MDfinish(dword* MDbuf, const byte* strptr, dword lswlen, dword mswlen) {
     // byte i goes into word X[i div 4] at pos.  8*(i mod 4)
     X[i >> 2] ^= static_cast<dword>(*strptr++) << (8 * (i & 3));
   }
-  // append the bit m_n == 1
+  // append the bit n_ == 1
   X[(lswlen >> 2) & 15] ^= static_cast<dword>(1) << (8 * (lswlen & 3) + 7);
   if ((lswlen & 63) > 55) {
     // length goes to next block
@@ -394,8 +393,8 @@ void ripemd_160(std::array<uint8_t, 20>& storage, const std::string& data) {
   length = static_cast<dword>(data.size());
   // process message in 16-word chunks
   for (dword nbytes = length; nbytes > 63; nbytes -= 64) {
-    for (dword i = 0; i < 16; ++i) {
-      X[i] = BYTES_TO_DWORD(message);
+    for (auto& i : X) {
+      i = BYTES_TO_DWORD(message);
       message += 4;
     }
     compress(MDbuf, X);
